mindroot.coreplugins.env\_manager package
=========================================

Submodules
----------

mindroot.coreplugins.env\_manager.mod module
--------------------------------------------

.. automodule:: mindroot.coreplugins.env_manager.mod
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.env\_manager.router module
-----------------------------------------------

.. automodule:: mindroot.coreplugins.env_manager.router
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: mindroot.coreplugins.env_manager
   :members:
   :show-inheritance:
   :undoc-members:
